==> open-cluster-management-observability-model-6.5.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpec;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpecBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpecFluentImpl;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservabilityAddonFluentImpl<A extends ObservabilityAddonFluent<A>> extends BaseFluent<A> implements ObservabilityAddonFluent<A>{
  public ObservabilityAddonFluentImpl() {
  }
  public ObservabilityAddonFluentImpl(ObservabilityAddon instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ObservabilityAddonSpecBuilder spec;
  private ObservabilityAddonStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ObservabilityAddonFluent.MetadataNested<A> withNewMetadata() {
    return new ObservabilityAddonFluentImpl.MetadataNestedImpl();
  }
  public ObservabilityAddonFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ObservabilityAddonFluentImpl.MetadataNestedImpl(item);
  }
  public ObservabilityAddonFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ObservabilityAddonFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ObservabilityAddonFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObservabilityAddonSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ObservabilityAddonSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ObservabilityAddonSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ObservabilityAddonSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ObservabilityAddonFluent.SpecNested<A> withNewSpec() {
    return new ObservabilityAddonFluentImpl.SpecNestedImpl();
  }
  public ObservabilityAddonFluent.SpecNested<A> withNewSpecLike(ObservabilityAddonSpec item) {
    return new ObservabilityAddonFluentImpl.SpecNestedImpl(item);
  }
  public ObservabilityAddonFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ObservabilityAddonFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ObservabilityAddonSpecBuilder().build());
  }
  public ObservabilityAddonFluent.SpecNested<A> editOrNewSpecLike(ObservabilityAddonSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObservabilityAddonStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ObservabilityAddonStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ObservabilityAddonStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ObservabilityAddonStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ObservabilityAddonFluent.StatusNested<A> withNewStatus() {
    return new ObservabilityAddonFluentImpl.StatusNestedImpl();
  }
  public ObservabilityAddonFluent.StatusNested<A> withNewStatusLike(ObservabilityAddonStatus item) {
    return new ObservabilityAddonFluentImpl.StatusNestedImpl(item);
  }
  public ObservabilityAddonFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ObservabilityAddonFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ObservabilityAddonStatusBuilder().build());
  }
  public ObservabilityAddonFluent.StatusNested<A> editOrNewStatusLike(ObservabilityAddonStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObservabilityAddonFluentImpl that = (ObservabilityAddonFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ObservabilityAddonFluent.MetadataNested<N>> implements ObservabilityAddonFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ObservabilityAddonSpecFluentImpl<ObservabilityAddonFluent.SpecNested<N>> implements ObservabilityAddonFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ObservabilityAddonSpec item) {
      this.builder = new ObservabilityAddonSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ObservabilityAddonSpecBuilder(this);
    }
    ObservabilityAddonSpecBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ObservabilityAddonStatusFluentImpl<ObservabilityAddonFluent.StatusNested<N>> implements ObservabilityAddonFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ObservabilityAddonStatus item) {
      this.builder = new ObservabilityAddonStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ObservabilityAddonStatusBuilder(this);
    }
    ObservabilityAddonStatusBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> open-cluster-management-observability-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta1/ObservabilityAddonFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta1;

import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpec;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpecBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.shared.ObservabilityAddonSpecFluentImpl;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservabilityAddonFluentImpl<A extends ObservabilityAddonFluent<A>> extends BaseFluent<A> implements ObservabilityAddonFluent<A>{
  public ObservabilityAddonFluentImpl() {
  }
  public ObservabilityAddonFluentImpl(ObservabilityAddon instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ObservabilityAddonSpecBuilder spec;
  private ObservabilityAddonStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ObservabilityAddonFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ObservabilityAddonFluentImpl.MetadataNestedImpl();
  }
  public ObservabilityAddonFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ObservabilityAddonFluentImpl.MetadataNestedImpl(item);
  }
  public ObservabilityAddonFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ObservabilityAddonFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ObservabilityAddonFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObservabilityAddonSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ObservabilityAddonSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ObservabilityAddonSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ObservabilityAddonSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ObservabilityAddonFluentImpl.SpecNested<A> withNewSpec() {
    return new ObservabilityAddonFluentImpl.SpecNestedImpl();
  }
  public ObservabilityAddonFluentImpl.SpecNested<A> withNewSpecLike(ObservabilityAddonSpec item) {
    return new ObservabilityAddonFluentImpl.SpecNestedImpl(item);
  }
  public ObservabilityAddonFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ObservabilityAddonFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ObservabilityAddonSpecBuilder().build());
  }
  public ObservabilityAddonFluentImpl.SpecNested<A> editOrNewSpecLike(ObservabilityAddonSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObservabilityAddonStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ObservabilityAddonStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ObservabilityAddonStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ObservabilityAddonStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ObservabilityAddonFluentImpl.StatusNested<A> withNewStatus() {
    return new ObservabilityAddonFluentImpl.StatusNestedImpl();
  }
  public ObservabilityAddonFluentImpl.StatusNested<A> withNewStatusLike(ObservabilityAddonStatus item) {
    return new ObservabilityAddonFluentImpl.StatusNestedImpl(item);
  }
  public ObservabilityAddonFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ObservabilityAddonFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ObservabilityAddonStatusBuilder().build());
  }
  public ObservabilityAddonFluentImpl.StatusNested<A> editOrNewStatusLike(ObservabilityAddonStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObservabilityAddonFluentImpl that = (ObservabilityAddonFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ObservabilityAddonFluentImpl.MetadataNested<N>> implements ObservabilityAddonFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ObservabilityAddonSpecFluentImpl<ObservabilityAddonFluentImpl.SpecNested<N>> implements ObservabilityAddonFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ObservabilityAddonSpec item) {
      this.builder = new ObservabilityAddonSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ObservabilityAddonSpecBuilder(this);
    }
    ObservabilityAddonSpecBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ObservabilityAddonStatusFluentImpl<ObservabilityAddonFluentImpl.StatusNested<N>> implements ObservabilityAddonFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ObservabilityAddonStatus item) {
      this.builder = new ObservabilityAddonStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ObservabilityAddonStatusBuilder(this);
    }
    ObservabilityAddonStatusBuilder builder;
    public N and() {
      return (N) ObservabilityAddonFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
